Stan Math Library: stan/math/rev/core/vd_vari.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

vd_vari.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_VD_VARI_HPP
2 #define STAN_MATH_REV_CORE_VD_VARI_HPP
3
4 #include <stan/math/rev/core/vari.hpp>
5
6 namespace stan {
7 namespace math {
8
9 class op_vd_vari : public vari {
10 protected:
11 vari* avi_;
12 double bd_;
13 public:
14 op_vd_vari(double f, vari* avi, double b) :
15 vari(f),
16 avi_(avi),
17 bd_(b) {
18 }
19 };
20
21 }
22 }
23 #endif
stan::math::op_vd_vari::op_vd_vari
op_vd_vari(double f, vari *avi, double b)
Definition: vd_vari.hpp:14
stan::math::op_vd_vari::avi_
vari * avi_
Definition: vd_vari.hpp:11
vari.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::vari
The variable implementation base class.
Definition: vari.hpp:30
stan::math::op_vd_vari::bd_
double bd_
Definition: vd_vari.hpp:12
stan::math::op_vd_vari
Definition: vd_vari.hpp:9

[ Stan Home Page ] © 2011–2016, Stan Development Team.